package widebase.rq

import msgpack.rpcx.Proxy

/** RQ Client.
 *
 * @param host of server
 * @param port of server
 * @param username to login
 * @param password to login
 *
 * @author myst3r10n
 */
abstract class Client(
  host: String,
  port: Int,
  username: String = "",
  password: String = "")
  extends msgpack.rpcx.Client(host, port)
  with Proxy {

  /** Sends periodically heartbeat to broker. */
  protected var alive: Thread = null

  /** Heartbeat frequency. */
  val frequency = 30000

  /** Logout from broker and release resources. */
  def shutdown {

    if(alive != null && !alive.isInterrupted)
      alive.interrupt

    logout
    release

  }

  /** Login to broker and startup heartbeat. */
  def start {

    login(username, password)

    alive = new Thread {

      override def run {

        try {

          while(true) {

            heartbeat
            Thread.sleep(frequency)

          }
        } catch {
          case e => // Alive stopped.

        }
      }
    }

    alive.start

  }
}

