package widebase.rq

import vario.filter.StreamFilter

import widebase.db.table.Table
import widebase.rq.interface.ConsumerInterface
import widebase.rq.listener.RecordListener

/** Consumer Client.
 *
 * @param host of server
 * @param port of server
 * @param username to login
 * @param password to login
 *
 * @author myst3r10n
 */
class ConsumerClient(
  host: String,
  port: Int,
  username: String = "",
  password: String = "")
  extends Client(host, port, username, password)
  with ConsumerProxy {

  import vario.filter.StreamFilter.StreamFilter

  /** Receives records from broker. */
  protected var receiver: Thread = null

  /** proxy to [[widebase.rq.ConsumerInterface]]. */
  override protected val proxy = client.proxy(classOf[ConsumerInterface])

  requestTimeout = Int.MaxValue

  override def shutdown {

    unsubscribe

    if(receiver != null && !receiver.isInterrupted)
      receiver.interrupt

    super.shutdown

  }

  /** Login to broker and subscribe table.
   *
   * @param listener of consumer
   * @param name of table to subscribe
   * @param selector to filter records
   * @param filter to extract binary records
   */
  def start(
    listener: RecordListener,
    name: String,
    selector: String = null)
    (implicit filter: StreamFilter = StreamFilter.None) {

    super.start

    subscribe(name, selector)

    val map = rollback
    val records = map.get("records").toInt
    val partition = map.get("partition")
    listener.onRollback(records, partition)

    receiver = new Thread {

      override def run {

        try {

          var bytes: Array[Byte] = null
          var table: Table = null

          while(true) {

            bytes = next

            if(bytes.isEmpty)
              listener.onEndOfDay
            else {

              table = Table.fromBytes(bytes, filter)
              listener.onUpsert(table)

            }
          }
        } catch {
          case e => // Receiver stopped.

        }
      }
    }

    receiver.start

  }
}

