package widebase.rq

import msgpack.rpcx.Proxy

import widebase.rq.interface.ConsumerInterface

/** Proxy to [[widebase.rq.ConsumerInterface]].
 *
 * @author myst3r10n
 */
trait ConsumerProxy extends Proxy {

  /** Proxy to consumer interface. */
  protected val proxy: ConsumerInterface

  /** Indicate ready to receive.
   *
   * @return bytes of records
   */
  protected def next = proxy.next(authId)

  /** Shutdown server remotelly. */
  def remoteShutdown {

    proxy.remoteShutdown(authId)

  }

  /** Receive rollback information.
   *
   * @return pair of records/partition
   */
  protected def rollback = proxy.rollback(authId)

  /** Subscribe table.
   *
   * @param name of table
   * @param selector to filter records
   */
  protected def subscribe(name: String, selector: String = null) {

    proxy.subscribe(authId, name, selector)

  }

  /** Unsubscribe table. */
  protected def unsubscribe {

    proxy.unsubscribe(authId)

  }
}

