package widebase.rq

import widebase.util.SysProps

/** Scope properties.
 *
 * Set directly or by system properties.
 *
 * Global property keys:
 * {{{
 * widebase.io. { filter }
 * }}}
 *
 * Package property keys:
 * {{{
 * widebase.rq. { filter }
 * }}}
 *
 * Individual property keys:
 * {{{
 * widebase.rq. { filters._ }
 * }}}
 *
 * @author myst3r10n
 */
object Props extends PropsLike {

  import vario.filter.StreamFilter.StreamFilter

  /** This package name. */
  override protected val packageName = "widebase.rq"

  /** Stream filter properties.
   *
   * @author myst3r10n
   */
  object filters {

    /** Used stream filter to upsert records. */
    var upsert: StreamFilter = _

    reset

    /** Resets stream filter properties. */
    def reset {

      upsert = SysProps.getFilter(packageName + ".filters.upsert", defaultFilter)

    }
  }
}

