package widebase

import msgpack.rpcx.auth.AuthMap

import vario.filter.StreamFilter

import widebase.rq.handler.BrokerHandler

/** RQ package
 *
 * @author myst3r10n
 */
package object rq {

  import vario.filter.StreamFilter.StreamFilter

  /** Create [[widebase.rq.Broker]] instance.
   *
   * @param handler alternative
   *
   * @return instance of [[widebase.rq.Broker]]
   */
  def broker(handler: BrokerHandler) = new Broker(handler)

  /** Create [[widebase.rq.Broker]] instance.
   *
   * @param path to rollback database
   * @param jaas entry name
   * @param auths procedure based authorizations
   * @param interval to publish
   * @param filter self-explenatory
   *
   * @return instance of [[widebase.rq.Broker]]
   */
  def broker(
    path: String,
    jaas: String,
    auths: AuthMap,
    interval: Int,
    filter: StreamFilter) =
    new Broker(path, jaas, auths, interval, filter)

  /** Create [[widebase.rq.Broker]] instance.
   *
   * @param path to rollback database
   * @param jaas entry name
   * @param auths procedure based authorizations
   * @param interval to publish
   * @param filter self-explenatory
   *
   * @return instance of [[widebase.rq.Broker]]
   */
  def broker(
    path: String,
    jaas: String,
    auths: AuthMap,
    interval: Int = 0,
    filter: String = "") = {

    val streamFilter =
      if(filter.contains("g"))
        StreamFilter.Gzip
      else
        StreamFilter.None

    new Broker(path, jaas, auths, interval, streamFilter)

  }

  /** Create [[widebase.rq.ConsumerClient]] instance.
   *
   * @param host of server
   * @param port of server
   * @param username to login
   * @param password to login
   *
   * @return instance of [[widebase.rq.ConsumerClient]]
   */
  def consumer(
    host: String,
    port: Int,
    username: String = "",
    password: String = "") =
    new ConsumerClient(host, port, username, password)

  /** Create [[widebase.rq.ProducerClient]] instance.
   *
   * @param host of server
   * @param port of server
   * @param username to login
   * @param password to login
   *
   * @return instance of [[widebase.rq.ProducerClient]]
   */
  def producer(
    host: String,
    port: Int,
    username: String = "",
    password: String = "") =
    new ProducerClient(host, port, username, password)

  /** Scope properties. */
  def props = Props

}

